Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PzTaskItem ¶
type PzTaskItem struct {
Data WorkOutData `json:"data"`
}
PzTaskItem exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.
type WorkBody ¶
type WorkBody struct {
Content string `json:"content"`
}
WorkBody exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.
type WorkDataInputs ¶
type WorkDataInputs struct {
Body WorkBody `json:"body"`
}
WorkDataInputs exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.
type WorkInData ¶
type WorkInData struct {
DataInputs WorkDataInputs `json:"dataInputs"`
}
WorkInData exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.
type WorkOutData ¶
type WorkOutData struct {
SvcData WorkSvcData `json:"serviceData"`
}
WorkOutData exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.
type WorkSvcData ¶
type WorkSvcData struct {
Data WorkInData `json:"data"`
JobID string `json:"jobId"`
}
WorkSvcData exists as part of the response format of the Piazza job manager task request endpoint. specifically, it's one layer of the bit we care about.